<?php

namespace Bixo\Asset\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Asset\Actions\AssetAction;
use Bixo\Asset\Http\Requests\AssetActionRequest;
use Bixo\Asset\Http\Resources\AssetResource;
use Bixo\Asset\Models\Asset;

/**
 * Admin web controller class.
 */
class AssetActionController extends BaseController
{

    /**
     * Action controller function for asset.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(AssetActionRequest $request, Asset $asset, $action)
    {
        try {
            $request = $request->all();
            $asset = AssetAction::run($action, $asset, $request);

            $data = new AssetResource($asset);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('asset::asset.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('asset/asset/' . $asset->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('asset/asset/' . $asset->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
