<?php
namespace Bixo\Asset\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Asset\Events\AssetAction as AssetActionEvent;
use Bixo\Asset\Models\Asset;

class AssetAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $asset;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param AssetActionEvent $asset
     */
    public function __construct(AssetActionEvent $asset)
    {
        $this->action = $event->action;
        $this->asset = $asset;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Asset Approved - ' . config('app.name'))
            ->view('asset::asset.email.action', ['data' => $this->asset]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
